@@ -42,16 +42,16 @@ extern GstTool *tool;
 void
 on_shares_table_selection_changed (GtkTreeSelection *selection, gpointer data)
 {
-	GtkWidget *settings_button, *delete_button;
+	GtkWidget *edit_share, *delete_share;
 	gboolean   active;
 
-	settings_button = gst_dialog_get_widget (tool->main_dialog, "edit_share");
-	delete_button   = gst_dialog_get_widget (tool->main_dialog, "delete_share");
+	edit_share = gst_dialog_get_widget (tool->main_dialog, "edit_share");
+	delete_share = gst_dialog_get_widget (tool->main_dialog, "delete_share");
 
 	active = (gtk_tree_selection_count_selected_rows (selection) > 0);
 
-	gtk_widget_set_sensitive (settings_button, active);
-	gtk_widget_set_sensitive (delete_button, active);
+	gst_dialog_try_set_sensitive (tool->main_dialog, edit_share, active);
+	gst_dialog_try_set_sensitive (tool->main_dialog, delete_share, active);
 }
 
 static void
@@ -167,7 +167,7 @@ on_edit_share_clicked (GtkWidget *widget, gpointer data)
 
 	gtk_tree_model_get (model, &iter, COL_PATH, &path, -1);
 
-	share_settings_dialog_run (path, FALSE);
+	share_settings_dialog_run_for_iter (path, &iter, FALSE);
 	g_free (path);
 }
 
@@ -201,9 +201,13 @@ on_delete_share_clicked (GtkWidget *widget, gpointer data)
 				GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT,
 				NULL);
 
+	gst_dialog_add_edit_dialog (tool->main_dialog, dialog);
+
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
+	gst_dialog_remove_edit_dialog (tool->main_dialog, dialog);
+
 	if (response == GTK_RESPONSE_ACCEPT) {
 		gtk_tree_model_get (model, &iter,
 				    COL_SHARE, &share,
@@ -286,10 +290,14 @@ on_share_nfs_add_clicked (GtkWidget *widget, gpointer data)
 
 	dialog = share_nfs_add_hosts_dialog_prepare ();
 
+	gst_dialog_add_edit_dialog (tool->main_dialog, dialog);
+
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_hide (dialog);
 
+	gst_dialog_remove_edit_dialog (tool->main_dialog, dialog);
+
 	if (response == GTK_RESPONSE_OK) {
 		if (!share_nfs_add_hosts_dialog_get_data (&host, &read_only))
 			return;
@@ -336,7 +344,8 @@ on_dialog_validate (GtkWidget *widget, gpointer data)
 	GtkWidget *ok_button;
 
 	ok_button = gst_dialog_get_widget (tool->main_dialog, "share_properties_ok");
-	gtk_widget_set_sensitive (ok_button, share_settings_validate ());
+	gst_dialog_try_set_sensitive (tool->main_dialog, ok_button,
+				      share_settings_validate ());
 }
 
 void
